@@ -2,11 +2,11 @@
 #include "myheader.h"
 void distRandGenC(double *SigmaInv, double *logdet, int *nrow, double *uvec, double *mu, double *distRandGenVal)
 {
-	double *umu=Calloc(*nrow,double);
+	double *umu=R_Calloc(*nrow,double);
 	/* calculates umu = uvec-mu */
 	subvec(uvec,mu,nrow,umu);
 
-	double *blah=Calloc(*nrow,double);
+	double *blah=R_Calloc(*nrow,double);
 	/* calculates blah=SigmaInv%*%umu  */
 	matvecmult(SigmaInv,umu,nrow,nrow,blah);
 	double blah2;
@@ -14,7 +14,7 @@ void distRandGenC(double *SigmaInv, double *logdet, int *nrow, double *uvec, dou
 	/*calculates blah2=t(umu)%*%Sigma.inv %*% umu */
 	matTvecmult(umu,blah,nrow,ione,&blah2);
 
-	Free(blah);
-	Free(umu);
-	*distRandGenVal=.5*((-*nrow)*log(2*PI)+ (*logdet)-blah2);
+	R_Free(blah);
+	R_Free(umu);
+	*distRandGenVal=.5*((-*nrow)*log(2*M_PI)+ (*logdet)-blah2);
 }
